==> swf-visualizer-0.1.1.tgz: package/src/components/visualizer-info/visualization-container/visualization-menu-config/room-house-edit-help/room-house-edit-help.jsx <==
import React from 'react'
import { Image } from 'react-bootstrap'
import AutoDetectSvg from '@assets/images/Visualizers-images/roominmyhouse/png/auto_detect.png'
import AddWindowSvg from '@assets/images/Visualizers-images/roominmyhouse/png/add_window.png'
import RemoveWindowSvg from '@assets/images/Visualizers-images/roominmyhouse/png/remove_window.png'
import VisualizeSvg from '@assets/images/Visualizers-images/roominmyhouse/png/visualize.png'
import './room-house-edit-help.scss'

const RoomHouseEditHelp = ({ openVisualizer }) => {

  const menuOptionList = [
    {
      id: 1,
      name: 'Auto Detect Windows',
      icon: AutoDetectSvg,
      fun: () => {}
    },
    {
      id: 2,
      name: 'Add Another Window',
      icon: AddWindowSvg,
      fun: () => {}
    },
    {
      id: 3,
      name: 'Remove Window',
      icon: RemoveWindowSvg,
      fun: () => {}
    },
    {
      id: 4,
      name: 'Visualize Room',
      icon: VisualizeSvg,
      fun: openVisualizer
    }
  ]

  return (
      <>
        <div className='panel_flex'>
          <div className='panel_inner_flex'>
            <span className='panel-text'>
              Fine-tune the frame by dragging the dots to each window corner. Do
              not forget to set the width.
            </span>
            
            {
              menuOptionList && menuOptionList.map(menuItem => (
                  <i className='panel-wide-button' key={menuItem.id} onClick={menuItem.fun}>
                    <Image src={menuItem.icon} width={24} height={24} />
                    {menuItem.name}
                  </i>
                )
              )
            }
          </div>
        </div>
      </>
  )
}

export default RoomHouseEditHelp

==> swf-visualizer-0.5.0.tgz: package/src/components/visualizer-info/visualization-container/visualization-menu-config/room-house-edit-help/room-house-edit-help.jsx <==
import React from 'react'
import { Image } from 'react-bootstrap'
import AutoDetectSvg from '@assets/images/roominmyhouse/png/auto_detect.png'
import AddWindowSvg from '@assets/images/roominmyhouse/png/add_window.png'
import RemoveWindowSvg from '@assets/images/roominmyhouse/png/remove_window.png'
import VisualizeSvg from '@assets/images/roominmyhouse/png/visualize.png'
import './room-house-edit-help.scss'

const RoomHouseEditHelp = ({ openVisualizer }) => {

  const menuOptionList = [
    {
      id: 1,
      name: 'Auto Detect Windows',
      icon: AutoDetectSvg,
      fun: () => {}
    },
    {
      id: 2,
      name: 'Add Another Window',
      icon: AddWindowSvg,
      fun: () => {}
    },
    {
      id: 3,
      name: 'Remove Window',
      icon: RemoveWindowSvg,
      fun: () => {}
    },
    {
      id: 4,
      name: 'Visualize Room',
      icon: VisualizeSvg,
      fun: openVisualizer
    }
  ]

  return (
      <>
        <div className='panel_flex'>
          <div className='panel_inner_flex'>
            <span className='panel-text'>
              Fine-tune the frame by dragging the dots to each window corner. Do
              not forget to set the width.
            </span>
            
            {
              menuOptionList && menuOptionList.map(menuItem => (
                  <i className='panel-wide-button' key={menuItem.id} onClick={menuItem.fun}>
                    <Image src={menuItem.icon} width={24} height={24} />
                    {menuItem.name}
                  </i>
                )
              )
            }
          </div>
        </div>
      </>
  )
}

export default RoomHouseEditHelp
